@@ -15,10 +15,13 @@ from UnleashClient.strategies import ApplicationHostname, Default, GradualRollou
     GradualRolloutSessionId, GradualRolloutUserId, UserWithId, RemoteAddress, FlexibleRollout
 from UnleashClient.constants import METRIC_LAST_SENT_TIME, DISABLED_VARIATION, ETAG
 from UnleashClient.loader import load_features
-from .utils import LOGGER
+from .utils import LOGGER, InstanceCounter, InstanceAllowType
 from .deprecation_warnings import strategy_v2xx_deprecation_check
 from .cache import BaseCache, FileCache
 
+
+INSTANCES = InstanceCounter()
+
 # pylint: disable=dangerous-default-value
 class UnleashClient:
     """
@@ -41,6 +44,7 @@ class UnleashClient:
     :param cache: Custom cache implementation that extends UnleashClient.cache.BaseCache.  When unset, UnleashClient will use Fcache.
     :param scheduler: Custom APScheduler object.  Use this if you want to customize jobstore or executors.  When unset, UnleashClient will create it's own scheduler.
     :param scheduler_executor: Name of APSCheduler executor to use if using a custom scheduler.
+    :param multiple_instance_mode: Determines how multiple instances being instantiated is handled by the SDK, when set to InstanceAllowType.BLOCK, the client constructor will fail when more than one instance is detected, when set to InstanceAllowType.WARN, multiple instances will be allowed but log a warning, when set to InstanceAllowType.SILENTLY_ALLOW, no warning or failure will be raised when instantiating multiple instances of the client. Defaults to InstanceAllowType.WARN
     """
     def __init__(self,
                  url: str,
@@ -61,7 +65,8 @@ class UnleashClient:
                  verbose_log_level: int = 30,
                  cache: Optional[BaseCache] = None,
                  scheduler: Optional[BaseScheduler] = None,
-                 scheduler_executor: Optional[str] = None) -> None:
+                 scheduler_executor: Optional[str] = None,
+                 multiple_instance_mode: InstanceAllowType = InstanceAllowType.WARN) -> None:
         custom_headers = custom_headers or {}
         custom_options = custom_options or {}
         custom_strategies = custom_strategies or {}
@@ -86,6 +91,8 @@ class UnleashClient:
         self.unleash_project_name = project_name
         self.unleash_verbose_log_level = verbose_log_level
 
+        self._do_instance_check(multiple_instance_mode)
+
         # Class objects
         self.features: dict = {}
         self.fl_job: Job = None
@@ -171,6 +178,7 @@ class UnleashClient:
         """
         # Only perform initialization steps if client is not initialized.
         if not self.is_initialized:
+            # pylint: disable=no-else-raise
             try:
                 # Setup
                 metrics_args = {
@@ -326,6 +334,21 @@ class UnleashClient:
             LOGGER.log(self.unleash_verbose_log_level, "Attempted to get feature flag/variation %s, but client wasn't initialized!", feature_name)
             return DISABLED_VARIATION
 
+    def _do_instance_check(self, multiple_instance_mode):
+        identifier = self.__get_identifier()
+        if identifier in INSTANCES:
+            msg = f"You already have {INSTANCES.count(identifier)} instance(s) configured for this config: {identifier}, please double check the code where this client is being instantiated."
+            if multiple_instance_mode == InstanceAllowType.BLOCK:
+                # pylint: disable=broad-exception-raised
+                raise Exception(msg)
+            if multiple_instance_mode == InstanceAllowType.WARN:
+                LOGGER.error(msg)
+        INSTANCES.increment(identifier)
+
+    def __get_identifier(self):
+        api_key = self.unleash_custom_headers.get("Authorization") if self.unleash_custom_headers is not None else None
+        return f"apiKey:{api_key} appName:{self.unleash_app_name} instanceId:{self.unleash_instance_id}"
+
     def __enter__(self) -> "UnleashClient":
         self.initialize_client()
         return self
