@@ -6,9 +6,10 @@ SDK_VERSION = version("UnleashClient")
 REQUEST_TIMEOUT = 30
 REQUEST_RETRIES = 3
 METRIC_LAST_SENT_TIME = "mlst"
+CLIENT_SPEC_VERSION = "4.2.2"
 
 # =Unleash=
-APPLICATION_HEADERS = {"Content-Type": "application/json", "Unleash-Client-Spec": "4.2.0"}
+APPLICATION_HEADERS = {"Content-Type": "application/json", "Unleash-Client-Spec": CLIENT_SPEC_VERSION}
 DISABLED_VARIATION = {
     'name': 'disabled',
     'enabled': False
